/*
 * deviced
 *
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include <stdbool.h>

#include "core/common.h"
#include "core/log.h"
#include "display/core.h"
#include "display/poll.h"

#define BUFF_MAX	255
#define LOCK_STR_MAX	20
#define DISP_LOCK_STR	"displock"
#define MAIN_LOCK_STR	"mainlock"
#define DIM_LOCK_STR	"dimlock"

#define USER_WAKELOCK_NODE	"/sys/power/slave_wake_lock"
#define USER_WAKEUNLOCK_NODE	"/sys/power/slave_wake_unlock"

static bool userlock_saving_support;

int save_pmlock(enum state_t state, bool on, pid_t pid)
{
	int ret = 0;
	char *node, *state_str;
	char str[LOCK_STR_MAX];

	if (!userlock_saving_support)
		return -ENOSYS;

	switch (state) {
	case S_NORMAL:
		state_str = DISP_LOCK_STR;
		break;
	case S_LCDDIM:
		state_str = DIM_LOCK_STR;
		break;
	case S_LCDOFF:
		state_str  = MAIN_LOCK_STR;
		break;
	default:
		return -EINVAL;
	}

	node = (on ? USER_WAKELOCK_NODE : USER_WAKEUNLOCK_NODE);

	snprintf(str, LOCK_STR_MAX, "%s %d", state_str, pid);

	ret = sys_set_str(node, str);
	if (ret < 0)
		_E("Failed to set disp userlock state!");

	return ret;
}

void init_save_userlock(void)
{
	int ret;
	char str[BUFF_MAX];

	userlock_saving_support = false;

	ret = sys_get_str(USER_WAKELOCK_NODE, str, sizeof(str));
	if (ret < 0) {
		_E("Failed to load userlock(lock)!");
		return;
	}

	ret = sys_get_str(USER_WAKEUNLOCK_NODE, str, sizeof(str));
	if (ret < 0) {
		_E("Failed to load userlock(unlock)!");
		return;
	}

	userlock_saving_support = true;
	_I("userlock-saving is enabled!");
}

